@@ -3,13 +3,13 @@ package chezmoi
 import (
 	"fmt"
 	"io/fs"
+	"maps"
 	"reflect"
+	"slices"
 	"strings"
 
 	"github.com/mitchellh/mapstructure"
 	"github.com/spf13/cobra"
-
-	"github.com/twpayne/chezmoi/v2/internal/chezmoimaps"
 )
 
 // An EntryTypeSet is a set of entry types. It parses and prints as a
@@ -64,7 +64,7 @@ var (
 		"templates": EntryTypeTemplates,
 	}
 
-	entryTypeStrings = chezmoimaps.SortedKeys(entryTypeBits)
+	entryTypeStrings = slices.Sorted(maps.Keys(entryTypeBits))
 
 	entryTypeCompletions = []string{
 		"all",
