@@ -10,10 +10,22 @@ import (
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
+const (
+	severityIgnore  = "ignore"
+	severityWarning = "warning"
+	severityError   = "error"
+)
+
+var severityValues = []string{
+	severityIgnore,
+	severityWarning,
+	severityError,
+}
+
 type addCmdConfig struct {
-	Encrypt          bool     `json:"encrypt"          mapstructure:"encrypt"          yaml:"encrypt"`
-	Secrets          severity `json:"secrets"          mapstructure:"secrets"          yaml:"secrets"`
-	TemplateSymlinks bool     `json:"templateSymlinks" mapstructure:"templateSymlinks" yaml:"templateSymlinks"`
+	Encrypt          bool        `json:"encrypt"          mapstructure:"encrypt"          yaml:"encrypt"`
+	Secrets          *choiceFlag `json:"secrets"          mapstructure:"secrets"          yaml:"secrets"`
+	TemplateSymlinks bool        `json:"templateSymlinks" mapstructure:"templateSymlinks" yaml:"templateSymlinks"`
 	autoTemplate     bool
 	create           bool
 	exact            bool
@@ -53,7 +65,8 @@ func (c *Config) newAddCmd() *cobra.Command {
 	addCmd.Flags().BoolVarP(&c.Add.prompt, "prompt", "p", c.Add.prompt, "Prompt before adding each entry")
 	addCmd.Flags().BoolVarP(&c.Add.quiet, "quiet", "q", c.Add.quiet, "Suppress warnings")
 	addCmd.Flags().BoolVarP(&c.Add.recursive, "recursive", "r", c.Add.recursive, "Recurse into subdirectories")
-	addCmd.Flags().Var(&c.Add.Secrets, "secrets", "Scan for secrets when adding unencrypted files")
+	addCmd.Flags().Var(c.Add.Secrets, "secrets", "Scan for secrets when adding unencrypted files")
+	must(addCmd.RegisterFlagCompletionFunc("secrets", c.Add.Secrets.FlagCompletionFunc()))
 	addCmd.Flags().BoolVarP(&c.Add.template, "template", "T", c.Add.template, "Add files as templates")
 	addCmd.Flags().
 		BoolVar(&c.Add.TemplateSymlinks, "template-symlinks", c.Add.TemplateSymlinks, "Add symlinks with target in source or home dirs as templates")
@@ -69,7 +82,7 @@ func (c *Config) defaultOnIgnoreFunc(targetRelPath chezmoi.RelPath) {
 
 func (c *Config) defaultPreAddFunc(targetRelPath chezmoi.RelPath, fileInfo fs.FileInfo) error {
 	// Scan unencrypted files for secrets, if configured.
-	if c.Add.Secrets != severityIgnore && fileInfo.Mode().Type() == 0 && !c.Add.Encrypt {
+	if c.Add.Secrets.String() != severityIgnore && fileInfo.Mode().Type() == 0 && !c.Add.Encrypt {
 		absPath := c.DestDirAbsPath.Join(targetRelPath)
 		content, err := c.destSystem.ReadFile(absPath)
 		if err != nil {
@@ -83,7 +96,7 @@ func (c *Config) defaultPreAddFunc(targetRelPath chezmoi.RelPath, fileInfo fs.Fi
 		for _, finding := range findings {
 			c.errorf("%s:%d: %s\n", absPath, finding.StartLine+1, finding.Description)
 		}
-		if !c.force && c.Add.Secrets == severityError && len(findings) > 0 {
+		if !c.force && c.Add.Secrets.String() == severityError && len(findings) > 0 {
 			return chezmoi.ExitCodeError(1)
 		}
 	}
@@ -164,6 +177,15 @@ func (c *Config) defaultReplaceFunc(
 }
 
 func (c *Config) runAddCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
+	switch severity := c.Add.Secrets.String(); severity {
+	case severityIgnore:
+	case severityWarning:
+	case severityError:
+		break
+	default:
+		return fmt.Errorf("%s: invalid severity", severity)
+	}
+
 	destAbsPathInfos, err := c.destAbsPathInfos(sourceState, args, destAbsPathInfosOptions{
 		follow:       c.Mode == chezmoi.ModeSymlink || c.Add.follow,
 		onIgnoreFunc: c.defaultOnIgnoreFunc,
