@@ -1,11 +1,17 @@
 package cmd
 
 import (
+	"cmp"
+
 	"github.com/spf13/cobra"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
+type dataCmdConfig struct {
+	format *choiceFlag
+}
+
 func (c *Config) newDataCmd() *cobra.Command {
 	dataCmd := &cobra.Command{
 		Use:     "data",
@@ -19,7 +25,8 @@ func (c *Config) newDataCmd() *cobra.Command {
 		),
 	}
 
-	dataCmd.Flags().VarP(&c.Format, "format", "f", "Output format")
+	dataCmd.Flags().VarP(c.data.format, "format", "f", "Output format")
+	must(dataCmd.RegisterFlagCompletionFunc("format", c.data.format.FlagCompletionFunc()))
 
 	return dataCmd
 }
@@ -31,5 +38,5 @@ func (c *Config) runDataCmd(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
-	return c.marshal(c.Format, sourceState.TemplateData())
+	return c.marshal(cmp.Or(c.data.format.String(), c.Format.String()), sourceState.TemplateData())
 }
